
NavX API
========

This is not installed on the Robot by default. For installation instructions,
see :ref:`robotpy-navx install docs <install_navx>`.

NavX AHRS Interface
-------------------

.. autoclass:: navx.AHRS
    :members:
    :undoc-members:
    :show-inheritance:

    
